==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/StackedSeriesCreatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { StackedSeriesCreatedEventArgsDescription } from "./StackedSeriesCreatedEventArgsDescription";
/**
 * @hidden
 */
export let StackedSeriesCreatedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSeriesCreatedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSeriesCreatedEventArgsDescriptionMetadata.a == null) {
                StackedSeriesCreatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSeriesCreatedEventArgsDescriptionMetadata.c(StackedSeriesCreatedEventArgsDescriptionMetadata.a);
            }
            if (a.j(StackedSeriesCreatedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(StackedSeriesCreatedEventArgsDescriptionMetadata.a);
            StyleDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Brush", "Brush");
            a.item("LegendItemTemplateRef", "(w:LegendItemTemplate,wf:LegendItemTemplate)DataRef::object");
            a.item("LegendItemBadgeTemplateRef", "(w:LegendItemBadgeTemplate,wf:LegendItemBadgeTemplate)DataRef::object");
            a.item("LegendItemVisibility", "ExportedType:string:Visibility");
            a.item("LegendItemVisibility@names", "Visible;Collapsed");
            a.item("Outline", "Brush");
            a.item("Thickness", "Number:double");
            a.item("TitleRef", "(w:Title,wf:Title)DataRef");
            a.item("TransitionDuration", "Number:int");
            a.item("TransitionEasingFunctionRef", "(w:TransitionEasingFunction,wf:TransitionEasingFunction)MethodRef");
            a.item("MarkerBrush", "Brush");
            a.item("MarkerOutline", "Brush");
            a.item("MarkerStyle", "ExportedType:Style");
            a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
            a.item("MarkerType", "ExportedType:string:MarkerType");
            a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
            a.item("MarkerThickness", "Number:double");
        }
        static d(a) {
            StackedSeriesCreatedEventArgsDescriptionMetadata.b(a);
            a.aa("StackedSeriesCreatedEventArgs", () => new StackedSeriesCreatedEventArgsDescription());
            a.z("StackedSeriesCreatedEventArgs", StackedSeriesCreatedEventArgsDescriptionMetadata.a);
        }
    }
    StackedSeriesCreatedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSeriesCreatedEventArgsDescriptionMetadata, 'StackedSeriesCreatedEventArgsDescriptionMetadata');
    StackedSeriesCreatedEventArgsDescriptionMetadata.a = null;
    return StackedSeriesCreatedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StackedSeriesCreatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { StackedSeriesCreatedEventArgsDescription } from "./StackedSeriesCreatedEventArgsDescription";
/**
 * @hidden
 */
export let StackedSeriesCreatedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSeriesCreatedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSeriesCreatedEventArgsDescriptionMetadata.a == null) {
                StackedSeriesCreatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSeriesCreatedEventArgsDescriptionMetadata.c(StackedSeriesCreatedEventArgsDescriptionMetadata.a);
            }
            if (a.k(StackedSeriesCreatedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(StackedSeriesCreatedEventArgsDescriptionMetadata.a);
            StyleDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Brush", "Brush");
            a.item("LegendItemTemplateRef", "(w:LegendItemTemplate,wf:LegendItemTemplate)DataRef::object");
            a.item("LegendItemBadgeTemplateRef", "(w:LegendItemBadgeTemplate,wf:LegendItemBadgeTemplate)DataRef::object");
            a.item("LegendItemVisibility", "ExportedType:string:Visibility");
            a.item("LegendItemVisibility@names", "Visible;Collapsed");
            a.item("Outline", "Brush");
            a.item("Thickness", "Number:double");
            a.item("TitleRef", "(w:Title,wf:Title)DataRef");
            a.item("TransitionDuration", "Number:int");
            a.item("TransitionEasingFunctionRef", "(w:TransitionEasingFunction,wf:TransitionEasingFunction)MethodRef");
            a.item("MarkerBrush", "Brush");
            a.item("MarkerOutline", "Brush");
            a.item("MarkerStyle", "ExportedType:Style");
            a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
            a.item("MarkerType", "ExportedType:string:MarkerType");
            a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
            a.item("MarkerThickness", "Number:double");
        }
        static d(a) {
            StackedSeriesCreatedEventArgsDescriptionMetadata.b(a);
            a.ac("StackedSeriesCreatedEventArgs", () => new StackedSeriesCreatedEventArgsDescription());
            a.ab("StackedSeriesCreatedEventArgs", StackedSeriesCreatedEventArgsDescriptionMetadata.a);
        }
    }
    StackedSeriesCreatedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSeriesCreatedEventArgsDescriptionMetadata, 'StackedSeriesCreatedEventArgsDescriptionMetadata');
    StackedSeriesCreatedEventArgsDescriptionMetadata.a = null;
    return StackedSeriesCreatedEventArgsDescriptionMetadata;
})();
